@@ -2,8 +2,9 @@
 
 from .mysolr_response import SolrResponse
 from .mysolr import Solr
+from .mysolr import Cursor
 
 __title__ = 'mysolr'
-__version__ = '0.5.1'
-__build__ = 0x000051
+__version__ = '0.6'
+__build__ = 0x000060
 __author__ = 'Rubén Abad, Miguel Olivares'
